@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -113,7 +113,7 @@ mod tests {
         state::merkle::INDEXES,
     };
     use transact::{
-        families::command::workload::CommandTransactionBuilder,
+        families::command::CommandTransactionBuilder,
         protocol::command::{BytesEntry, Command, SetState},
     };
 
